==> quarkus-cache-deployment-2.3.1.Final-sources.jar: io/quarkus/cache/deployment/CacheConfig$CaffeineConfig$CaffeineNamespaceConfig$$accessor.java <==
package io.quarkus.cache.deployment;
public final class CacheConfig$CaffeineConfig$CaffeineNamespaceConfig$$accessor {
    private CacheConfig$CaffeineConfig$CaffeineNamespaceConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_initialCapacity(Object __instance) {
        return ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).initialCapacity;
    }
    @SuppressWarnings("unchecked")
    public static void set_initialCapacity(Object __instance, Object initialCapacity) {
        ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).initialCapacity = (java.util.OptionalInt)initialCapacity;
    }
    @SuppressWarnings("unchecked")
    public static Object get_maximumSize(Object __instance) {
        return ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).maximumSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_maximumSize(Object __instance, Object maximumSize) {
        ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).maximumSize = (java.util.OptionalLong)maximumSize;
    }
    @SuppressWarnings("unchecked")
    public static Object get_expireAfterWrite(Object __instance) {
        return ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).expireAfterWrite;
    }
    @SuppressWarnings("unchecked")
    public static void set_expireAfterWrite(Object __instance, Object expireAfterWrite) {
        ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).expireAfterWrite = (java.util.Optional<java.time.Duration>)expireAfterWrite;
    }
    @SuppressWarnings("unchecked")
    public static Object get_expireAfterAccess(Object __instance) {
        return ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).expireAfterAccess;
    }
    @SuppressWarnings("unchecked")
    public static void set_expireAfterAccess(Object __instance, Object expireAfterAccess) {
        ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).expireAfterAccess = (java.util.Optional<java.time.Duration>)expireAfterAccess;
    }
}

==> quarkus-cache-deployment-2.15.1.Final-sources.jar: io/quarkus/cache/deployment/CacheConfig$CaffeineConfig$CaffeineNamespaceConfig$$accessor.java <==
package io.quarkus.cache.deployment;
public final class CacheConfig$CaffeineConfig$CaffeineNamespaceConfig$$accessor {
    private CacheConfig$CaffeineConfig$CaffeineNamespaceConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static Object get_initialCapacity(Object __instance) {
        return ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).initialCapacity;
    }
    @SuppressWarnings("unchecked")
    public static void set_initialCapacity(Object __instance, Object initialCapacity) {
        ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).initialCapacity = (java.util.OptionalInt)initialCapacity;
    }
    @SuppressWarnings("unchecked")
    public static Object get_maximumSize(Object __instance) {
        return ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).maximumSize;
    }
    @SuppressWarnings("unchecked")
    public static void set_maximumSize(Object __instance, Object maximumSize) {
        ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).maximumSize = (java.util.OptionalLong)maximumSize;
    }
    @SuppressWarnings("unchecked")
    public static Object get_expireAfterWrite(Object __instance) {
        return ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).expireAfterWrite;
    }
    @SuppressWarnings("unchecked")
    public static void set_expireAfterWrite(Object __instance, Object expireAfterWrite) {
        ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).expireAfterWrite = (java.util.Optional<java.time.Duration>)expireAfterWrite;
    }
    @SuppressWarnings("unchecked")
    public static Object get_expireAfterAccess(Object __instance) {
        return ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).expireAfterAccess;
    }
    @SuppressWarnings("unchecked")
    public static void set_expireAfterAccess(Object __instance, Object expireAfterAccess) {
        ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).expireAfterAccess = (java.util.Optional<java.time.Duration>)expireAfterAccess;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_metricsEnabled(Object __instance) {
        return ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).metricsEnabled;
    }
    @SuppressWarnings("unchecked")
    public static void set_metricsEnabled(Object __instance, boolean metricsEnabled) {
        ((io.quarkus.cache.deployment.CacheConfig.CaffeineConfig.CaffeineNamespaceConfig)__instance).metricsEnabled = metricsEnabled;
    }
}
